@@ -1,18 +1,18 @@
 /*
   ZynAddSubFX - a software synthesizer
- 
+
   Filter_.h - This class is inherited by filter classes
   Copyright (C) 2002-2005 Nasca Octavian Paul
   Author: Nasca Octavian Paul
 
   This program is free software; you can redistribute it and/or modify
-  it under the terms of version 2 of the GNU General Public License 
+  it under the terms of version 2 of the GNU General Public License
   as published by the Free Software Foundation.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License (version 2) for more details.
+  GNU General Public License (version 2 or later) for more details.
 
   You should have received a copy of the GNU General Public License (version 2)
   along with this program; if not, write to the Free Software Foundation,
@@ -25,16 +25,17 @@
 
 #include "../globals.h"
 
-class Filter_{
- public:
-    virtual ~Filter_(){};	
-    virtual void filterout(REALTYPE *smp){};
-    virtual void setfreq(REALTYPE frequency){};
-    virtual void setfreq_and_q(REALTYPE frequency,REALTYPE q_){};
-    virtual void setq(REALTYPE q_){};
-    virtual void setgain(REALTYPE dBgain){};
+class Filter_
+{
+public:
+    virtual ~Filter_() {};
+    virtual void filterout(REALTYPE *smp)=0;
+    virtual void setfreq(REALTYPE frequency)=0;
+    virtual void setfreq_and_q(REALTYPE frequency,REALTYPE q_)=0;
+    virtual void setq(REALTYPE q_)=0;
+    virtual void setgain(REALTYPE dBgain) {};
     REALTYPE outgain;
- private:
+private:
 };
 
 
