@@ -1,18 +1,18 @@
 /*
   ZynAddSubFX - a software synthesizer
- 
+
   ALSAMidiIn.h - Midi input for ALSA (this creates an ALSA virtual port)
   Copyright (C) 2002-2005 Nasca Octavian Paul
   Author: Nasca Octavian Paul
 
   This program is free software; you can redistribute it and/or modify
-  it under the terms of version 2 of the GNU General Public License 
+  it under the terms of version 2 of the GNU General Public License
   as published by the Free Software Foundation.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License (version 2) for more details.
+  GNU General Public License (version 2 or later) for more details.
 
   You should have received a copy of the GNU General Public License (version 2)
   along with this program; if not, write to the Free Software Foundation,
@@ -27,16 +27,23 @@
 #include "MidiIn.h"
 
 
-class ALSAMidiIn:public MidiIn{
-    public:
-	ALSAMidiIn();
-	~ALSAMidiIn();
-	void getmidicmd(MidiCmdType &cmdtype,unsigned char &cmdchan,int *cmdparams);
+/**Midi input for ALSA (this creates an ALSA virtual port)*/
+class ALSAMidiIn:public MidiIn
+{
+public:
+    /**Constructor*/
+    ALSAMidiIn();
+    /**Destructor*/
+    ~ALSAMidiIn();
 
-    private:
-	snd_seq_t *midi_handle;
+    void getmidicmd(MidiCmdType &cmdtype,unsigned char &cmdchan,int *cmdparams);
+    /**Get the ALSA id
+     * @return ALSA id*/
+    int getalsaid();
+
+private:
+    snd_seq_t *midi_handle;
 };
 
-
 #endif
 
